# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gradle_bodyguard', 'gradle_bodyguard.utils']

package_data = \
{'': ['*']}

install_requires = \
['flake8>=3.8.2,<4.0.0', 'requests>=2.23.0,<3.0.0']

entry_points = \
{'console_scripts': ['gradle-bodyguard = gradle_bodyguard:main']}

setup_kwargs = {
    'name': 'gradle-bodyguard',
    'version': '0.0.3',
    'description': 'A tool that scans dependencies in your Gradle project and warns you about potential security issues',
    'long_description': '# Gradle Bodyguard\n\n<!--![](.github/assets/showcase.gif)\n-->\n## What is this?\n\n> *Complete blog post to come. Stay tunned!*\n\n[Supply chain attacks](https://arstechnica.com/information-technology/2020/04/725-bitcoin-stealing-apps-snuck-into-ruby-repository/) are a reality and the JVM ecosystem is not imune. \n\nThere are several tools out there that help developers from JVM-based languages to counter measure against supply chain attacks - like [Dependabot](https://dependabot.com/), [Synk](https://snyk.io/), [DependencyCheck](https://github.com/jeremylong/DependencyCheck) - and others. But when talking particularly about Gradle project things start to become a little more tricky, because (but only) :\n\n- We are instered not only in the dependencies that our project declares, but also in the transitive ones (actually, transitive dependencies are the main attack vector here);\n\n- Is quite common that Gradle projects - specially multi-module ones - manage dependencies either with [Project extension](https://docs.gradle.org/current/dsl/org.gradle.api.plugins.ExtraPropertiesExtension.html) API or with [buildSrc](https://docs.gradle.org/current/userguide/organizing_gradle_projects.html#sec:build_sources). In the two cases, tools like Dependabot - which parses your Gradle files in order to figure out dependencies - get confused or eventually don\'t find the dependencies;\n\n- Gradle plugins for such type of tools eventually are available, but this means another plugin in your Gradle build;\n\n- OWASP DependencyCheck is quite trick to be used in Android projects.\n\n\n`gradle-bodyguard` was born to tackle these issues. Written in Python and running as a CLI tool, it requires no additional plugins in your project and exercises your Gradle build - either root project only or multi-module one, regarless dependencies managed with `buildSrc` - and learns about the dependencies that **Gradle already knows about your project**, even the transitive ones. \n\n`gradle-bodyguard` match these artifacts against [OSS Index](https://ossindex.sonatype.org/) and outputs the results for you. In this way, you can learn (and automate around) when some dependency introduces a new disclosed [CVE](https://en.wikipedia.org/wiki/Common_Vulnerabilities_and_Exposures) in your build, particularly at CI level.\n\nBecause OSSIndex is free to use, this tool is free of charge as well. 😎\n\n## Setup\n\nInstall with [pip](https://www.w3schools.com/python/python_pip.asp). Requires Python 3.8.+ or newer installed in your machine.\n\n```bash\n→ pip install gradle-bodyguard\n```\n\n## Using\n\nThe most basic usage takes only a path to the target Gradle project you want to examine:\n\n```bash\n→ gradle-bodyguard -p <path-to-gradle-project>\n```\n\nYou should see results in your terminal screen 🔥\n\nYou also can have a `json` version of the security report. This file is only generated when the tool find potential vulnerabilities :\n\n```bash\n→ gradle-bodyguard -p <path-to-gradle-project> -d <path-to-folder>\n```\n\nThe `gradle-bodyguard-report.json` file will be stored at `folder`\n\nIf you realise that some CVEs actually don\'t impact your project at all, you can just ignore them and exclude such CVEs from the results\n\n```bash\n→ gradle-bodyguard -p <path-to-gradle-project> -i <CVE-ID>,<CVE-ID>,<CVE-ID>\n```\n\nSee usage for a full list of options\n\n```bash\n→ gradle-bodyguard --help\n```\n\n## Using as a Github Action\n\nComing soon 🔥\n\n## Limitations\n\nAs mentioned previously, `gradle-bodyguard` is backed by the amazing [OSS Index](https://ossindex.sonatype.org/), offered by [Sonatype](https://ossindex.sonatype.org/). If you were not aware of this product until now, you should have a look.\n\nOne limitation that `gradle-bodyguard` has is the following : this tool does not require your OSS Index `API TOKEN` for [authenticated REST API calls](https://ossindex.sonatype.org/doc/rest); **bodyguard** avoids that by batching the dependencies computed in the Gradle project and querying 125 Maven coordinates per HTTP request - since this option is [available at all](https://ossindex.sonatype.org/rest#/Component%20vulnerability%20reports/post). \n\nThis should work fine for most of small/medium projects out there(up to 500 dependencies including the transitive ones), and therefore the usage of the tool is a bit simpler as well.\n\nIf your project consumes way more dependencies than aforementioned and you started to see `429s` in logs when using `gradle-bodyguard`, fill an issue with a feature request, I\'ll be happy to implement that.\n\n\n## Credits\n\nI\'d like to thank in special : \n\n- [Python Poetry](https://python-poetry.org/) because it allowed a newcomer in the Python ecosystem to build and ship his first package on Pypi with an amazing developer experience\n- [Sonatype](https://ossindex.sonatype.org/) for providing OSSIndex (and its companion REST API) for free to the open-source community\n\n\n## Author\n\nCoded by Ubiratan Soares (follow me on [Twitter](https://twitter.com/ubiratanfsoares))\n\n## License\n\n```\nThe MIT License (MIT)\n\nCopyright (c) 2020 Dotanuki Labs\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the "Software"), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of\nthe Software, and to permit persons to whom the Software is furnished to do so,\nsubject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\nFOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER\nIN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\nCONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n```',
    'author': 'Ubiratan Soares',
    'author_email': 'ubiratan.f.soares@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/dotanuki-labs/gradle-bodyguard',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
